import jwt
import json
from django.conf import settings


class JWTAuthorizationMiddleware(object):
    def resolve(self, next, root, info, **args):
        request = info.context

        if self.is_introspect(request):
            return next(root, info, **args)

        auth_header = request.META.get("HTTP_AUTHORIZATION", "")
        token = auth_header.replace("Bearer ", "")

        if token:
            self.decode_jwt(token)
            return next(root, info, **args)

        raise Exception("You do not have permission to perform this action")

    def is_introspect(self, request):
        body = request._body.decode('utf-8')

        if not body:
            return None

        operation_name = json.loads(body).get("operationName", "")
        introspect_values = ["SubgraphIntrospectQuery", "IntrospectionQuery"]

        return operation_name in introspect_values

    def decode_jwt(self, token):
        try:
            jwt.decode(
                token,
                settings.SECRET_KEY,
                algorithms=["HS256"],
            )
        except jwt.ExpiredSignatureError:
            raise Exception("Signature has expired")
        except jwt.DecodeError:
            raise Exception("Error decoding token")
        except jwt.InvalidTokenError:
            raise Exception("Invalid token")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['graphene_django_jwt_middleware']

package_data = \
{'': ['*']}

install_requires = \
['django>=2.2.6,<3.0.0', 'pyjwt>=2.4.0,<3.0.0']

setup_kwargs = {
    'name': 'graphene-django-jwt-middleware',
    'version': '0.0.1',
    'description': 'Middleware to check JWT validation in GraphQL schemas',
    'long_description': '# Graphene Django JWT Middleware\n\nThis is a [Graphene Django](https://docs.graphene-python.org/projects/django/en/latest/) middleware to check JWT in GraphQL schemas.\n',
    'author': 'Instruct Developers',
    'author_email': 'oss@instruct.com.br',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/instruct-br/graphene-django-jwt-middleware',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
